==> boo_0.7.5.2013.orig.tar.gz: boo-0.7.5.2013/src/Boo.Lang.Parser/WSABooTokenTypes.cs <==
﻿#region license
// Copyright (c) 2003, 2004, 2005 Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion


// $ANTLR 2.7.5 (20050517): "wsaboo.g" -> "WSABooLexer.cs"$

namespace Boo.Lang.Parser
{
	public class WSABooTokenTypes
	{
		public const int EOF = 1;
		public const int NULL_TREE_LOOKAHEAD = 3;
		public const int ELIST = 4;
		public const int DLIST = 5;
		public const int ESEPARATOR = 6;
		public const int ABSTRACT = 7;
		public const int AND = 8;
		public const int AS = 9;
		public const int AST = 10;
		public const int BREAK = 11;
		public const int CONTINUE = 12;
		public const int CALLABLE = 13;
		public const int CAST = 14;
		public const int CHAR = 15;
		public const int CLASS = 16;
		public const int CONSTRUCTOR = 17;
		public const int DEF = 18;
		public const int DESTRUCTOR = 19;
		public const int DO = 20;
		public const int ELIF = 21;
		public const int ELSE = 22;
		public const int END = 23;
		public const int ENSURE = 24;
		public const int ENUM = 25;
		public const int EVENT = 26;
		public const int EXCEPT = 27;
		public const int FAILURE = 28;
		public const int FINAL = 29;
		public const int FROM = 30;
		public const int FOR = 31;
		public const int FALSE = 32;
		public const int GET = 33;
		public const int GIVEN = 34;
		public const int GOTO = 35;
		public const int IMPORT = 36;
		public const int INTERFACE = 37;
		public const int INTERNAL = 38;
		public const int IS = 39;
		public const int ISA = 40;
		public const int IF = 41;
		public const int IN = 42;
		public const int NOT = 43;
		public const int NULL = 44;
		public const int OR = 45;
		public const int OTHERWISE = 46;
		public const int OVERRIDE = 47;
		public const int NAMESPACE = 48;
		public const int PUBLIC = 49;
		public const int PROTECTED = 50;
		public const int PRIVATE = 51;
		public const int RAISE = 52;
		public const int REF = 53;
		public const int RETURN = 54;
		public const int RETRY = 55;
		public const int SET = 56;
		public const int SELF = 57;
		public const int SUPER = 58;
		public const int STATIC = 59;
		public const int SUCCESS = 60;
		public const int STRUCT = 61;
		public const int TRY = 62;
		public const int TRANSIENT = 63;
		public const int TRUE = 64;
		public const int TYPEOF = 65;
		public const int UNLESS = 66;
		public const int VIRTUAL = 67;
		public const int PARTIAL = 68;
		public const int WHEN = 69;
		public const int WHILE = 70;
		public const int YIELD = 71;
		public const int EOS = 72;
		public const int TRIPLE_QUOTED_STRING = 73;
		public const int DOUBLE_QUOTED_STRING = 74;
		public const int SINGLE_QUOTED_STRING = 75;
		public const int ID = 76;
		public const int LPAREN = 77;
		public const int RPAREN = 78;
		public const int ASSIGN = 79;
		public const int SUBTRACT = 80;
		public const int LBRACK = 81;
		public const int COMMA = 82;
		public const int RBRACK = 83;
		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 84;
		public const int DOT = 85;
		public const int COLON = 86;
		public const int MULTIPLY = 87;
		public const int BITWISE_OR = 88;
		public const int LBRACE = 89;
		public const int RBRACE = 90;
		public const int INPLACE_BITWISE_OR = 91;
		public const int INPLACE_BITWISE_AND = 92;
		public const int INPLACE_SHIFT_LEFT = 93;
		public const int INPLACE_SHIFT_RIGHT = 94;
		public const int CMP_OPERATOR = 95;
		public const int GREATER_THAN = 96;
		public const int LESS_THAN = 97;
		public const int ADD = 98;
		public const int EXCLUSIVE_OR = 99;
		public const int DIVISION = 100;
		public const int MODULUS = 101;
		public const int BITWISE_AND = 102;
		public const int SHIFT_LEFT = 103;
		public const int SHIFT_RIGHT = 104;
		public const int EXPONENTIATION = 105;
		public const int INCREMENT = 106;
		public const int DECREMENT = 107;
		public const int ONES_COMPLEMENT = 108;
		public const int OF = 109;
		public const int INT = 110;
		public const int LONG = 111;
		public const int RE_LITERAL = 112;
		public const int DOUBLE = 113;
		public const int FLOAT = 114;
		public const int TIMESPAN = 115;
		public const int LINE_CONTINUATION = 116;
		public const int SL_COMMENT = 117;
		public const int ML_COMMENT = 118;
		public const int WS = 119;
		public const int X_RE_LITERAL = 120;
		public const int NEWLINE = 121;
		public const int ESCAPED_EXPRESSION = 122;
		public const int DQS_ESC = 123;
		public const int SQS_ESC = 124;
		public const int SESC = 125;
		public const int RE_CHAR = 126;
		public const int X_RE_CHAR = 127;
		public const int RE_ESC = 128;
		public const int DIGIT_GROUP = 129;
		public const int REVERSE_DIGIT_GROUP = 130;
		public const int ID_LETTER = 131;
		public const int DIGIT = 132;
		public const int HEXDIGIT = 133;
		
	}
}

==> boo_0.7.6.2237.orig.tar.gz: boo-0.7.6.2237/src/Boo.Lang.Parser/WSABooTokenTypes.cs <==
﻿#region license
// Copyright (c) 2003, 2004, 2005 Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion


// $ANTLR 2.7.5 (20050517): "src/Boo.Lang.Parser/wsaboo.g" -> "WSABooLexer.cs"$

namespace Boo.Lang.Parser
{
	public class WSABooTokenTypes
	{
		public const int EOF = 1;
		public const int NULL_TREE_LOOKAHEAD = 3;
		public const int ELIST = 4;
		public const int DLIST = 5;
		public const int ESEPARATOR = 6;
		public const int ABSTRACT = 7;
		public const int AND = 8;
		public const int AS = 9;
		public const int AST = 10;
		public const int BREAK = 11;
		public const int CONTINUE = 12;
		public const int CALLABLE = 13;
		public const int CAST = 14;
		public const int CHAR = 15;
		public const int CLASS = 16;
		public const int CONSTRUCTOR = 17;
		public const int DEF = 18;
		public const int DESTRUCTOR = 19;
		public const int DO = 20;
		public const int ELIF = 21;
		public const int ELSE = 22;
		public const int END = 23;
		public const int ENSURE = 24;
		public const int ENUM = 25;
		public const int EVENT = 26;
		public const int EXCEPT = 27;
		public const int FAILURE = 28;
		public const int FINAL = 29;
		public const int FROM = 30;
		public const int FOR = 31;
		public const int FALSE = 32;
		public const int GET = 33;
		public const int GIVEN = 34;
		public const int GOTO = 35;
		public const int IMPORT = 36;
		public const int INTERFACE = 37;
		public const int INTERNAL = 38;
		public const int IS = 39;
		public const int ISA = 40;
		public const int IF = 41;
		public const int IN = 42;
		public const int NOT = 43;
		public const int NULL = 44;
		public const int OR = 45;
		public const int OTHERWISE = 46;
		public const int OVERRIDE = 47;
		public const int NAMESPACE = 48;
		public const int PUBLIC = 49;
		public const int PROTECTED = 50;
		public const int PRIVATE = 51;
		public const int RAISE = 52;
		public const int REF = 53;
		public const int RETURN = 54;
		public const int RETRY = 55;
		public const int SET = 56;
		public const int SELF = 57;
		public const int SUPER = 58;
		public const int STATIC = 59;
		public const int SUCCESS = 60;
		public const int STRUCT = 61;
		public const int TRY = 62;
		public const int TRANSIENT = 63;
		public const int TRUE = 64;
		public const int TYPEOF = 65;
		public const int UNLESS = 66;
		public const int VIRTUAL = 67;
		public const int PARTIAL = 68;
		public const int WHEN = 69;
		public const int WHILE = 70;
		public const int YIELD = 71;
		public const int TRIPLE_QUOTED_STRING = 72;
		public const int EOS = 73;
		public const int DOUBLE_QUOTED_STRING = 74;
		public const int SINGLE_QUOTED_STRING = 75;
		public const int ID = 76;
		public const int LPAREN = 77;
		public const int RPAREN = 78;
		public const int ASSIGN = 79;
		public const int SUBTRACT = 80;
		public const int LBRACK = 81;
		public const int COMMA = 82;
		public const int RBRACK = 83;
		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 84;
		public const int DOT = 85;
		public const int COLON = 86;
		public const int MULTIPLY = 87;
		public const int BITWISE_OR = 88;
		public const int LBRACE = 89;
		public const int RBRACE = 90;
		public const int INPLACE_BITWISE_OR = 91;
		public const int INPLACE_BITWISE_AND = 92;
		public const int INPLACE_SHIFT_LEFT = 93;
		public const int INPLACE_SHIFT_RIGHT = 94;
		public const int CMP_OPERATOR = 95;
		public const int GREATER_THAN = 96;
		public const int LESS_THAN = 97;
		public const int ADD = 98;
		public const int EXCLUSIVE_OR = 99;
		public const int DIVISION = 100;
		public const int MODULUS = 101;
		public const int BITWISE_AND = 102;
		public const int SHIFT_LEFT = 103;
		public const int SHIFT_RIGHT = 104;
		public const int EXPONENTIATION = 105;
		public const int INCREMENT = 106;
		public const int DECREMENT = 107;
		public const int ONES_COMPLEMENT = 108;
		public const int OF = 109;
		public const int INT = 110;
		public const int LONG = 111;
		public const int RE_LITERAL = 112;
		public const int DOUBLE = 113;
		public const int FLOAT = 114;
		public const int TIMESPAN = 115;
		public const int LINE_CONTINUATION = 116;
		public const int SL_COMMENT = 117;
		public const int ML_COMMENT = 118;
		public const int WS = 119;
		public const int X_RE_LITERAL = 120;
		public const int NEWLINE = 121;
		public const int ESCAPED_EXPRESSION = 122;
		public const int DQS_ESC = 123;
		public const int SQS_ESC = 124;
		public const int SESC = 125;
		public const int RE_CHAR = 126;
		public const int X_RE_CHAR = 127;
		public const int RE_ESC = 128;
		public const int DIGIT_GROUP = 129;
		public const int REVERSE_DIGIT_GROUP = 130;
		public const int ID_PREFIX = 131;
		public const int ID_LETTER = 132;
		public const int DIGIT = 133;
		public const int HEXDIGIT = 134;
		
	}
}
